summaryrefslogtreecommitdiff
path: root/include/ec_ec_comm_server.h
diff options
context:
space:
mode:
authorDossym Nurmukhanov <dossym@google.com>2020-12-11 11:17:39 -0800
committerCommit Bot <commit-bot@chromium.org>2020-12-12 12:55:43 +0000
commit61022575d3c8b75d07e4f3be3f1616e45767f673 (patch)
tree236ac65b862e8bf1c825c5862e788a3ae783ee24 /include/ec_ec_comm_server.h
parenta86aecb2de50437622e91ee451079175cdef5e1d (diff)
downloadchrome-ec-61022575d3c8b75d07e4f3be3f1616e45767f673.tar.gz
COIL: Use inclusive language for EC-EC communication code
Replace with server/client nomenclature BUG=none TEST=build and run on volteer BRANCH=none Signed-off-by: dossym@chromium.org Change-Id: I23fe7de9228a9611b49eef1362bf15159b25aab7 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2586038 Reviewed-by: Nicolas Boichat <drinkcat@chromium.org>
Diffstat (limited to 'include/ec_ec_comm_server.h')
-rw-r--r--include/ec_ec_comm_server.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/ec_ec_comm_server.h b/include/ec_ec_comm_server.h
index 19e1912d94..1ed5588666 100644
--- a/include/ec_ec_comm_server.h
+++ b/include/ec_ec_comm_server.h
@@ -2,19 +2,19 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*
* EC-EC communication, functions and definition for slave.
*/
-#ifndef EC_EC_COMM_SLAVE_H_
-#define EC_EC_COMM_SLAVE_H_
+#ifndef EC_EC_COMM_SERVER_H_
+#define EC_EC_COMM_SERVER_H_
#include <stdint.h>
#include "consumer.h"
#include "queue.h"
-extern struct queue const ec_ec_comm_slave_input;
-extern struct queue const ec_ec_comm_slave_output;
+extern struct queue const ec_ec_comm_server_input;
+extern struct queue const ec_ec_comm_server_output;
-void ec_ec_comm_slave_written(struct consumer const *consumer, size_t count);
+void ec_ec_comm_server_written(struct consumer const *consumer, size_t count);
-#endif /* EC_EC_COMM_SLAVE_H_ */
+#endif /* EC_EC_COMM_SERVER_H_ */
@@ -2,19 +2,19 @@
* found in the LICENSE file.
*
- * EC-EC communication, functions and definition for slave.
+ * EC-EC communication, functions and definition for server.
*/